@@ -165,6 +165,13 @@ AppWindow::refresh_panels()
     UI_diary->update_entry_list();
 }
 
+void
+AppWindow::fix_paned_positions_if_needed()
+{
+    if( m_Pd_extra->get_position() > ( Lifeograph::settings.height * 0.9 ) )
+        m_Pd_extra->set_position( Lifeograph::settings.height / 2 );
+}
+
 void
 AppWindow::show_entry( Entry* entry )
 {
@@ -256,13 +263,13 @@ AppWindow::handle_redo()
 void
 AppWindow::handle_login()
 {
-    if( m_paned_main == nullptr ) // first login
+    if( m_Pd_main == nullptr ) // first login
     {
         try
         {
             // PANES
-            Lifeograph::get_builder()->get_widget( "P_main", m_paned_main );
-            Lifeograph::get_builder()->get_widget( "P_second", m_paned_entry );
+            Lifeograph::get_builder()->get_widget( "P_main", m_Pd_main );
+            Lifeograph::get_builder()->get_widget( "P_second", m_Pd_extra );
 
             // ICONS
             Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
@@ -309,18 +316,18 @@ AppWindow::handle_login()
         // try to keep the same ratio between the panels before the resizing occurs:
         if( width != Lifeograph::settings.width )
         {
-            Lifeograph::settings.position_pane *=  float( width ) / Lifeograph::settings.width;
+            Lifeograph::settings.position_paned_main *=  float( width ) / Lifeograph::settings.width;
         }
 
         // check the diary panel's size against the minimum:
-        if( Lifeograph::settings.position_pane > ( width - UIDiary::MIN_WIDTH ) )
+        if( Lifeograph::settings.position_paned_main > ( width - UIDiary::MIN_WIDTH ) )
         {
             PRINT_DEBUG( "Diary panel width set to minimum value" );
-            Lifeograph::settings.position_pane = width - UIDiary::MIN_WIDTH;
+            Lifeograph::settings.position_paned_main = width - UIDiary::MIN_WIDTH;
         }
 
-        m_paned_main->set_position( Lifeograph::settings.position_pane );
-        m_paned_entry->set_position( Lifeograph::settings.position_pane_tags );
+        m_Pd_main->set_position( Lifeograph::settings.position_paned_main );
+        m_Pd_extra->set_position( Lifeograph::settings.position_paned_extra );
 
         // ACTIONS
         Lifeograph::p->add_action( "undo", [ this ](){ handle_undo(); } );
@@ -329,7 +336,7 @@ AppWindow::handle_login()
         Lifeograph::p->set_accel_for_action( "app.redo", "<Ctrl><Shift>Z" );
     }
 
-    m_St_main->set_visible_child( *m_paned_main );
+    m_St_main->set_visible_child( *m_Pd_main );
 
     update_toggle_auto_logout_gui( true );
 
@@ -470,8 +477,8 @@ bool
 AppWindow::finish_login_session( bool opt_save )
 {
     // SAVING
-    Lifeograph::settings.position_pane = m_paned_main->get_position();
-    Lifeograph::settings.position_pane_tags = m_paned_entry->get_position();
+    Lifeograph::settings.position_paned_main = m_Pd_main->get_position();
+    Lifeograph::settings.position_paned_extra = m_Pd_extra->get_position();
 
     // files added to recent list here if not already there
     if( ! Diary::d->get_path().empty() )
