@@ -183,22 +183,22 @@ Paragraph::has_tag_planned( const Entry* tag ) const
 bool
 Paragraph::has_tag_broad( const Entry* tag ) const
 {
-    if( m_tags.find( tag->get_name() ) != m_tags.end() )
-        return true;
+    if( has_tag( tag ) ) return true;
 
-    VecEntries&& children{ tag->get_descendants() };
+    VecEntries&& descendant_tags{ tag->get_descendants() };
 
-    for( auto& child_tag : children )
+    for( auto& child_tag : descendant_tags )
     {
-        if( has_tag_broad( child_tag ) ) // recursion
-            return true;
+        const Paragraph* para = this;
+
+        while( para )
+        {
+            if( para->has_tag( child_tag ) ) return true;
+            para = para->get_parent();
+        }
     }
 
-    auto parent_para = get_parent();
-    if( parent_para )
-        return parent_para->has_tag_broad( tag ); // recursion
-    else
-        return false;
+    return false;
 }
 
 Value
