@@ -219,8 +219,11 @@ class DiaryElement : public NamedElement
         DEID                    get_id() const
         { return m_id; }
 
+        bool                    is_equal_to( const DiaryElement* other ) const
+        { return( other->m_id == this->m_id ); }
+
         Diary*                  get_diary() const
-        { return m_ptr2diary; }
+        { return m_p2diary; }
 
         bool                    get_filtered_out() const
         { return( m_status & ES::FILTERED_OUT ); }
@@ -269,7 +272,7 @@ class DiaryElement : public NamedElement
         void                    set_id( DEID id )
         { m_id = id; }
 
-        Diary* const            m_ptr2diary{ nullptr };
+        Diary* const            m_p2diary{ nullptr };
 
         ElemStatus              m_status = ES::_VOID_;
 
@@ -404,7 +407,7 @@ class Paragraph
         const std::string           get_text_std() const // for file output
         { return m_text; }
         Ustring                     get_substr_after( UstringSize i ) const
-        { return m_text.substr( i, m_text.length() - i ); }
+        { return m_text.substr( i ); }
 
         UstringSize                 get_size() const
         { return m_text.length(); }
@@ -451,6 +454,7 @@ class Paragraph
             m_tags_in_order.push_back( tag );
         }
         bool                        has_tag( const Entry* ) const;
+        bool                        has_tag_planned( const Entry* ) const;
         bool                        has_tag_broad( const Entry* ) const; // in broad sense
         Value                       get_value_for_tag( const Entry*, int& ) const;
         Value                       get_value_planned_for_tag( const Entry*, int& ) const;
@@ -768,12 +772,12 @@ class ChartData
 
         static constexpr int    DEFAULT                 = MONTHLY|CUMULATIVE_CONTINUOUS;
 
-        ChartData( Diary* d, int t = DEFAULT ) : type( t ), m_ptr2diary( d ) { }
+        ChartData( Diary* d, int t = DEFAULT ) : type( t ), m_p2diary( d ) { }
 
         void                        clear();
 
         void                        set_diary( Diary* diary )
-        { m_ptr2diary = diary; }
+        { m_p2diary = diary; }
 
         std::string                 get_as_string() const;
         void                        set_from_string( const Ustring& );
@@ -840,7 +844,7 @@ class ChartData
             values_plan.push_back( v_plan );
         }
 
-        Diary*                      m_ptr2diary;
+        Diary*                      m_p2diary;
 };
 
 class ChartElem : public StringDefElem
@@ -1051,6 +1055,7 @@ class TableData
         { m_flag_group_by_first = F_enable; }
 
         void                        populate_lines();
+        void                        sort_lines( TableColumn* = nullptr );
 
         Ustring                     get_value_str( int, int ) const;
         Ustring                     get_total_value_str( int ) const;
