@@ -148,6 +148,7 @@ class ParserText
                   m_contents( oth->m_contents ), m_blocks( oth->m_blocks ),
                   m_index( oth->m_index ), m_pos_bgn( oth->m_pos_bgn ),
                   m_pos_mid( oth->m_pos_mid ), m_int_value( oth->m_int_value ),
+                  m_flag_accept_spaces( oth->m_flag_accept_spaces ),
                   m_state( oth->m_state ) { }
 
                 // for 2nd part recipes
@@ -157,7 +158,6 @@ class ParserText
                   m_blocks( b ), m_index( 0 ), m_pos_bgn( ps ), m_pos_mid( pm ),
                   m_int_value( m_parent->m_int_last ) { }
 
-                bool                        starts_with();
                 State                       process_char();
                 CharClass                   get_char_class_at( int i ) const
                 {
@@ -207,7 +207,6 @@ class ParserText
         static const Recipe::Id RID_IGNORE          = 0x1000;
         static const Recipe::Id RID_TODO            = 0x2000;
         static const Recipe::Id RID_DATE            = 0x4000;
-        static const Recipe::Id RID_EMAIL_END       = 0x20000;
         static const Recipe::Id RID_COLON           = 0x40000;
         static const Recipe::Id RID_LINK_AT         = 0x80000;
         static const Recipe::Id RID_GENERIC         = 0x100000;
