@@ -105,13 +105,13 @@ Settings::read()
                     small_lists = false;
                 break;
             case 'P':   // uppercase
-                position_pane = std::stol( line.substr( 2 ) );
+                position_paned_main = std::stol( line.substr( 2 ) );
                 break;
             case 'p':   // lowercase
-                position_pane_tags =  std::stol( line.substr( 2 ) );
+                position_paned_extra =  std::stol( line.substr( 2 ) );
                 // zero width is not accepted by Gtk::Paned
-                if( position_pane_tags == 0 )
-                    position_pane_tags = 1;
+                if( position_paned_extra == 0 )
+                    position_paned_extra = 1;
                 break;
             case 'R':
                 recentfiles.insert( line.substr( 2 ) );
@@ -172,8 +172,8 @@ Settings::write()
     file << "\nX " << position_x;
     file << "\nY " << position_y;
     file << "\nS " << ( state_maximized ? 'm' : 'u' );
-    file << "\nP " << position_pane;
-    file << "\np " << position_pane_tags;
+    file << "\nP " << position_paned_main;
+    file << "\np " << position_paned_extra;
 
     // RECENT FILES
     for( const std::string& path : recentfiles )
