@@ -757,10 +757,10 @@ WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator& itr1,
             direction = ( ( sc & SoCr_FILTER_DIR_T ) == SoCr_ASCENDING_T ? -1 : 1 );
     }
 
-    if( item1->get_date() > item2->get_date() )
+    if( item1->get_date_t() > item2->get_date_t() )
         return -direction;
     else
-    if( item1->get_date() < item2->get_date() )
+    if( item1->get_date_t() < item2->get_date_t() )
         return direction;
     else
         return 0;
