@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2021 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -998,9 +998,9 @@ TextbufferDiaryEdit::open_paragraph_below()
 
     Gtk::TextIter&& iter{ get_iter_at_mark( get_insert() ) };
     iter.forward_line();
-    iter = insert( iter, "\n" );
+    place_cursor( --iter );
 
-    place_cursor( iter.is_end() ? iter : --iter );
+    handle_new_line();
 }
 
 void
